@@ -150,7 +150,7 @@ void Calc::StoreConfig(Lum::Config::Node *top)
   Lum::Config::Node *node;
 
   node=new Lum::Config::Node(L"calculator");
-  node->SetAttribute(L"trigometricalMode",*calcTrigoMode);
+  node->SetAttribute(L"trigometricalMode",calcTrigoMode->Get());
 
   top->Add(node);
 }
