@@ -33,7 +33,7 @@ std::vector<Formula*> formulas;
 
 std::map<std::wstring,Unit*> unitMap;
 
-Lum::Model::SizeTRef calcTrigoMode=new Lum::Model::SizeT(1);
+Lum::Model::ULongRef calcTrigoMode=new Lum::Model::ULong(1);
 
 Alternative::Alternative(const std::wstring& name,
                          const std::wstring& symbol,
