@@ -40,8 +40,8 @@ class FormulaCalc : public Lum::Component, public ConfigPlugin
 private:
   Lum::Model::ActionRef              selectAction;
   Lum::Model::ActionRef              executeAction;
-  Lum::Model::SizeTRef               category;
-  Lum::Model::SizeTRef               subCategory;
+  Lum::Model::ULongRef               category;
+  Lum::Model::ULongRef               subCategory;
   Lum::Model::StringTableRef         categories;
   Lum::Model::StringTableRef         subCategories;
   FormulaModelRef                    functions;
