@@ -23,9 +23,11 @@
 
 #include <Lum/Button.h>
 #include <Lum/Grid.h>
+#include <Lum/Multi.h>
 #include <Lum/Panel.h>
 #include <Lum/Table.h>
-
+#include <Lum/Toggle.h>
+#include <iostream>
 class ButtonPopup : public Lum::Popup
 {
 protected:
@@ -73,99 +75,14 @@ public:
   }
 };
 
-class ConstantPopup : public ButtonPopup
-{
-public:
-  void PreInit()
-  {
-    Lum::Grid *grid;
-
-    grid=new Lum::Grid();
-    grid->SetFlex(true,true);
-    grid->SetSize(2,1);
-    grid->SetEqualDimensions(true,true);
-    grid->SetSpace(true,true);
-
-    grid->SetObject(0,0,CreateTextButton(L"\x03c0"/*L"pi"*/,L"pi"));
-    grid->SetObject(1,0,CreateTextButton(L"e"));
-
-    SetMain(grid,false,true);
-
-    ButtonPopup::PreInit();
-  }
-};
-
-class FunctionPopup : public ButtonPopup
-{
-public:
-  void PreInit()
-  {
-    Lum::Grid *grid;
-
-    grid=new Lum::Grid();
-    grid->SetFlex(true,true);
-    grid->SetSize(3,1);
-    grid->SetEqualDimensions(true,true);
-    grid->SetSpace(true,true);
-
-    grid->SetObject(0,0,CreateTextButton(L"^"));
-    grid->SetObject(1,0,CreateTextButton(L"ln",L"ln("));
-    grid->SetObject(2,0,CreateTextButton(L"lg",L"lg("));
-
-    grid->SetObject(0,1,CreateTextButton(L"\x221a"/*L"sqrt"*/,L"sqrt("));
-    grid->SetObject(1,1,CreateTextButton(L"abs",L"abs("));
-
-    SetMain(grid,false,true);
-
-    ButtonPopup::PreInit();
-  }
-};
-
-class TrigometricPopup : public ButtonPopup
-{
-public:
-  void PreInit()
-  {
-    Lum::Grid *grid;
-
-    grid=new Lum::Grid();
-    grid->SetFlex(true,true);
-    grid->SetSize(3,1);
-    grid->SetEqualDimensions(true,true);
-    grid->SetSpace(true,true);
-
-    grid->SetObject(0,0,CreateTextButton(L"sin",L"sin("));
-    grid->SetObject(1,0,CreateTextButton(L"cos",L"cos("));
-    grid->SetObject(2,0,CreateTextButton(L"tan",L"tan("));
-
-    grid->SetObject(0,1,CreateTextButton(L"asin",L"asin("));
-    grid->SetObject(1,1,CreateTextButton(L"acos",L"acos("));
-    grid->SetObject(2,1,CreateTextButton(L"atan",L"atan("));
-
-    grid->SetObject(0,2,CreateTextButton(L"sinh",L"sinh("));
-    grid->SetObject(1,2,CreateTextButton(L"cosh",L"cosh"));
-    grid->SetObject(2,2,CreateTextButton(L"tanh",L"tanh"));
-
-    grid->SetObject(0,3,CreateTextButton(L"asinh",L"asinh("));
-    grid->SetObject(1,3,CreateTextButton(L"acosh",L"acosh("));
-    grid->SetObject(2,3,CreateTextButton(L"atanh",L"atanh("));
-
-    SetMain(grid,false,true);
-
-    ButtonPopup::PreInit();
-  }
-};
-
 FunctionInput::FunctionInput()
- : constantAction(new Lum::Model::Action()),
-   functionAction(new Lum::Model::Action()),
-   trigometricAction(new Lum::Model::Action()),
+ : selectedPage(new Lum::Model::ULong(1)),
+   shownPage(new Lum::Model::ULong(0)),
    backspaceAction(new Lum::Model::Action()),
    clearAction(new Lum::Model::Action())
 {
-  Observe(constantAction);
-  Observe(functionAction);
-  Observe(trigometricAction);
+  Observe(selectedPage);
+
   Observe(backspaceAction);
   Observe(clearAction);
 }
@@ -180,7 +97,8 @@ void FunctionInput::SetCalculateAction(Lum::Model::Action* action)
   calculateAction=action;
 }
 
-Lum::Object* FunctionInput::CreateTextButton(const std::wstring& label, const std::wstring& text)
+Lum::Object* FunctionInput::CreateTextButton(const std::wstring& label,
+                                             const std::wstring& text)
 {
   Lum::Model::ActionRef action;
 
@@ -201,21 +119,29 @@ Lum::Object* FunctionInput::CreateTextButton(const std::wstring& label, const st
 void FunctionInput::CalcSize()
 {
   Lum::Grid   *grid;
+  Lum::Multi  *multi;
   Lum::Panel  *panel;
   Lum::Panel  *panel2;
 
   panel=Lum::HPanel::Create(true,true);
 
   panel2=Lum::VPanel::Create(false,true);
-  panel2->Add(constantButton=Lum::Button::Create(L"Constants",constantAction,true,false));
-  panel2->AddSpace();
-  panel2->Add(functionButton=Lum::Button::Create(L"Functions",functionAction,true,false));
-  panel2->AddSpace();
-  panel2->Add(trigometricButton=Lum::Button::Create(L"Trigonomie",trigometricAction,true,false));
+  panel2->Add(Lum::Toggle::Create(L"Standard",selectedPage,1,true,false));
+  panel2->Add(Lum::Toggle::Create(L"Constants",selectedPage,2,true,false));
+  panel2->Add(Lum::Toggle::Create(L"Functions",selectedPage,3,true,false));
+  panel2->Add(Lum::Toggle::Create(L"Trigonomie",selectedPage,4,true,false));
   panel2->AddSpace(true);
   panel->Add(panel2);
   panel->AddSpace(true);
 
+  multi=new Lum::Multi();
+  multi->SetFlex(true,true);
+  multi->SetModel(shownPage);
+
+  //
+  // Standard
+  //
+
   grid=new Lum::Grid();
   grid->SetFlex(true,true);
   grid->SetSize(5,4);
@@ -251,7 +177,71 @@ void FunctionInput::CalcSize()
   grid->SetObject(3,3,CreateTextButton(L"+"));
   grid->SetObject(4,3,CreateTextButton(L")"));
 
-  panel->Add(grid);
+  multi->Append(grid);
+
+  //
+  // Constants
+  //
+
+  grid=new Lum::Grid();
+  //grid->SetFlex(true,true);
+  grid->SetSize(2,1);
+  grid->SetEqualDimensions(true,true);
+  grid->SetSpace(true,true);
+
+  grid->SetObject(0,0,CreateTextButton(L"\x03c0"/*L"pi"*/,L"pi"));
+  grid->SetObject(1,0,CreateTextButton(L"e"));
+
+  multi->Append(grid);
+
+  //
+  // Functions
+  //
+
+  grid=new Lum::Grid();
+  //grid->SetFlex(true,true);
+  grid->SetSize(3,1);
+  grid->SetEqualDimensions(true,true);
+  grid->SetSpace(true,true);
+
+  grid->SetObject(0,0,CreateTextButton(L"^"));
+  grid->SetObject(1,0,CreateTextButton(L"ln",L"ln("));
+  grid->SetObject(2,0,CreateTextButton(L"lg",L"lg("));
+
+  grid->SetObject(0,1,CreateTextButton(L"\x221a"/*L"sqrt"*/,L"sqrt("));
+  grid->SetObject(1,1,CreateTextButton(L"abs",L"abs("));
+
+  multi->Append(grid);
+
+  //
+  // Trigonomie
+  //
+
+  grid=new Lum::Grid();
+  //grid->SetFlex(true,true);
+  grid->SetSize(3,1);
+  grid->SetEqualDimensions(true,true);
+  grid->SetSpace(true,true);
+
+  grid->SetObject(0,0,CreateTextButton(L"sin",L"sin("));
+  grid->SetObject(1,0,CreateTextButton(L"cos",L"cos("));
+  grid->SetObject(2,0,CreateTextButton(L"tan",L"tan("));
+
+  grid->SetObject(0,1,CreateTextButton(L"asin",L"asin("));
+  grid->SetObject(1,1,CreateTextButton(L"acos",L"acos("));
+  grid->SetObject(2,1,CreateTextButton(L"atan",L"atan("));
+
+  grid->SetObject(0,2,CreateTextButton(L"sinh",L"sinh("));
+  grid->SetObject(1,2,CreateTextButton(L"cosh",L"cosh"));
+  grid->SetObject(2,2,CreateTextButton(L"tanh",L"tanh"));
+
+  grid->SetObject(0,3,CreateTextButton(L"asinh",L"asinh("));
+  grid->SetObject(1,3,CreateTextButton(L"acosh",L"acosh("));
+  grid->SetObject(2,3,CreateTextButton(L"atanh",L"atanh("));
+
+  multi->Append(grid);
+
+  panel->Add(multi);
 
   container=panel;
 
@@ -260,65 +250,9 @@ void FunctionInput::CalcSize()
 
 void FunctionInput::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
 {
-  if (model==constantAction &&
-      constantAction->IsFinished()) {
-    ConstantPopup* popup=new ConstantPopup();
-
-    if (popup!=NULL) {
-      popup->SetParent(GetWindow());
-      popup->SetReference(constantButton);
-
-      if (popup->Open()) {
-        popup->EventLoop();
-        popup->Close();
-      }
-
-      if (!popup->GetResult().empty()) {
-        string->ActionInsertString(popup->GetResult());
-      }
-
-      delete popup;
-    }
-  }
-  else if (model==functionAction &&
-           functionAction->IsFinished()) {
-    FunctionPopup* popup=new FunctionPopup();
-
-    if (popup!=NULL) {
-      popup->SetParent(GetWindow());
-      popup->SetReference(functionButton);
-
-      if (popup->Open()) {
-        popup->EventLoop();
-        popup->Close();
-      }
-
-      if (!popup->GetResult().empty()) {
-        string->ActionInsertString(popup->GetResult());
-      }
-
-      delete popup;
-    }
-  }
-  else if (model==trigometricAction &&
-           trigometricAction->IsFinished()) {
-    TrigometricPopup* popup=new TrigometricPopup();
-
-    if (popup!=NULL) {
-      popup->SetParent(GetWindow());
-      popup->SetReference(functionButton);
-
-      if (popup->Open()) {
-        popup->EventLoop();
-        popup->Close();
-      }
-
-      if (!popup->GetResult().empty()) {
-        string->ActionInsertString(popup->GetResult());
-      }
-
-      delete popup;
-    }
+  if (model==selectedPage) {
+    std::cout << "Selected page: " << selectedPage->Get() << std::endl;
+    shownPage->Set(selectedPage->Get()-1);
   }
   else if (model==backspaceAction && backspaceAction->IsFinished()) {
     string->ActionBackspace();
@@ -333,6 +267,7 @@ void FunctionInput::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg&
     iter=actionTextMap.find(dynamic_cast<Lum::Model::Action*>(model));
     if (iter!=actionTextMap.end()) {
       string->ActionInsertString(iter->second);
+      shownPage->Set(0);
     }
   }
 
