@@ -23,6 +23,7 @@
 #include <map>
 
 #include <Lum/Model/Action.h>
+#include <Lum/Model/Number.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/Table.h>
 
@@ -34,15 +35,11 @@ class FunctionInput : public Lum::Component
 private:
   Lum::String                                *string;
   std::map<Lum::Model::Action*,std::wstring> actionTextMap;
-  Lum::Model::ActionRef                      constantAction;
-  Lum::Model::ActionRef                      functionAction;
-  Lum::Model::ActionRef                      trigometricAction;
+  Lum::Model::ULongRef                       selectedPage;
+  Lum::Model::ULongRef                       shownPage;
   Lum::Model::ActionRef                      backspaceAction;
   Lum::Model::ActionRef                      clearAction;
   Lum::Model::ActionRef                      calculateAction;
-  Lum::Button                                *constantButton;
-  Lum::Button                                *functionButton;
-  Lum::Button                                *trigometricButton;
 
 private:
   Lum::Object* CreateTextButton(const std::wstring& label, const std::wstring& text=L"");
