@@ -195,11 +195,12 @@ Lum::Object* FunctionsDialog::GetContent()
 
   table=new Lum::Table();
   table->SetFlex(true,true);
-  table->SetMinWidth(Lum::Base::Size::stdCharWidth,30);
   table->GetTableView()->SetMinHeight(Lum::Base::Size::stdCharHeight,6);
+  table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
   table->SetShowHeader(false);
   table->SetModel(functions);
+  table->SetPainter(new FunctionsPainter());
   table->SetHeaderModel(headerModel);
   table->SetSelection(selection);
   horiz->Add(table);
@@ -260,7 +261,7 @@ void FunctionsDialog::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg
   else if (model==updateAction && updateAction->IsFinished()) {
     if (selection->HasSelection()) {
       FunctionDialog        *dialog;
-      Lum::Model::StringRef function=new Lum::Model::String(functions->GetString(1,selection->GetLine()));
+      Lum::Model::StringRef function=new Lum::Model::String(functions->GetFunction(selection->GetLine()));
 
       dialog=new FunctionDialog(parser,function);
       dialog->SetParent(GetWindow());
@@ -370,10 +371,9 @@ public:
     horiz->AddSpace(true);
 
     string=new Lum::String();
-    string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
-    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
+    string->SetInputTypeHint(Lum::Object::inputTypeSignedFloatNumber);
     string->SetModel(topValue);
     horiz->Add(string);
 
@@ -388,20 +388,18 @@ public:
     horiz=Lum::HPanel::Create(true,false);
 
     string=new Lum::String();
-    string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
-    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
+    string->SetInputTypeHint(Lum::Object::inputTypeSignedFloatNumber);
     string->SetModel(leftValue);
     horiz->Add(string);
 
     horiz->AddSpace(true);
 
     string=new Lum::String();
-    string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
-    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
+    string->SetInputTypeHint(Lum::Object::inputTypeSignedFloatNumber);
     string->SetModel(rightValue);
     horiz->Add(string);
 
@@ -416,10 +414,9 @@ public:
     horiz->AddSpace(true);
 
     string=new Lum::String();
-    string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
-    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeFloat));
+    string->SetInputTypeHint(Lum::Object::inputTypeSignedFloatNumber);
     string->SetModel(bottomValue);
     horiz->Add(string);
 
@@ -605,7 +602,7 @@ void Plot::StoreConfig(Lum::Config::Node *top)
 
       node=new Lum::Config::Node();
       node->SetName(L"function");
-      node->SetAttribute(L"function",functions->GetString(1,row));
+      node->SetAttribute(L"function",functions->GetFunction(row));
 
       top->Add(node);
     }
