@@ -45,24 +45,13 @@ size_t Functions::GetRows() const
   return functions.size();
 }
 
-size_t Functions::GetColumns() const
+std::wstring Functions::GetFunction(size_t row) const
 {
-  return 1;
-}
-
-std::wstring Functions::GetString(size_t column, size_t row) const
-{
-  assert(column==1);
   assert(row>0 && row<=functions.size());
 
   return functions[row-1].function;
 }
 
-Lum::Object* Functions::GetObject(size_t column, size_t row) const
-{
-  return NULL;
-}
-
 Parser::Variable* Functions::GetPlotVar() const
 {
   return plotVar;
@@ -207,9 +196,10 @@ double Plotter::TransformY(size_t y)
   return (height-y)*(model->GetTop()-model->GetBottom())/(height-1)+model->GetBottom();
 }
 
-void Plotter::Draw(int x, int y, size_t w, size_t h)
+void Plotter::Draw(Lum::OS::DrawInfo* draw,
+                   int x, int y, size_t w, size_t h)
 {
-  Lum::Control::Draw(x,y,w,h);
+  Lum::Control::Draw(draw,x,y,w,h);
 
   if (!OIntersect(x,y,w,h)) {
     return;
@@ -221,7 +211,6 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
     return;
   }
 
-  Lum::OS::DrawInfo *draw=GetDrawInfo();
   Lum::OS::FontRef  font=Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote);
   double            a,b,startStep,endStep;
   int               count;
