@@ -33,11 +33,11 @@
 #include "Util.h"
 
 UnitConversion::UnitConversion()
- : type(new Lum::Model::SizeT()),
+ : type(new Lum::Model::ULong()),
    types(new Lum::Model::StringTable()),
-   src(new Lum::Model::SizeT()),
+   src(new Lum::Model::ULong()),
    srcUnits(new Lum::Model::StringTable()),
-   dest(new Lum::Model::SizeT()),
+   dest(new Lum::Model::ULong()),
    destUnits(new Lum::Model::StringTable()),
    value(new Lum::Model::String(L"")),
    result(new Lum::Model::String(L"")),
